@@ -98,7 +98,7 @@ impl<'a> NativeCallContext<'a> {
             lib,
         }
     }
-    /// _(INTERNALS)_ Create a new [`NativeCallContext`].
+    /// _(internals)_ Create a new [`NativeCallContext`].
     /// Exported under the `internals` feature only.
     ///
     /// Not available under `no_module`.
@@ -144,7 +144,6 @@ impl<'a> NativeCallContext<'a> {
     /// Not available under `no_module`.
     #[cfg(not(feature = "no_module"))]
     #[inline(always)]
-    #[must_use]
     pub fn iter_imports(&self) -> impl Iterator<Item = (&str, &Module)> {
         self.mods.iter().flat_map(|&m| m.iter())
     }
@@ -152,13 +151,12 @@ impl<'a> NativeCallContext<'a> {
     #[cfg(not(feature = "no_module"))]
     #[allow(dead_code)]
     #[inline(always)]
-    #[must_use]
     pub(crate) fn iter_imports_raw(
         &self,
     ) -> impl Iterator<Item = (&crate::Identifier, &Shared<Module>)> {
         self.mods.iter().flat_map(|&m| m.iter_raw())
     }
-    /// _(INTERNALS)_ The current set of modules imported via `import` statements.
+    /// _(internals)_ The current set of modules imported via `import` statements.
     /// Exported under the `internals` feature only.
     ///
     /// Not available under `no_module`.
@@ -171,11 +169,10 @@ impl<'a> NativeCallContext<'a> {
     }
     /// Get an iterator over the namespaces containing definitions of all script-defined functions.
     #[inline(always)]
-    #[must_use]
     pub fn iter_namespaces(&self) -> impl Iterator<Item = &Module> {
         self.lib.iter().cloned()
     }
-    /// _(INTERNALS)_ The current set of namespaces containing definitions of all script-defined functions.
+    /// _(internals)_ The current set of namespaces containing definitions of all script-defined functions.
     /// Exported under the `internals` feature only.
     #[cfg(feature = "internals")]
     #[inline(always)]
@@ -195,8 +192,7 @@ impl<'a> NativeCallContext<'a> {
     ///
     /// If `is_method` is [`true`], the first argument is assumed to be passed
     /// by reference and is not consumed.
-    #[inline(always)]
-    #[must_use]
+    #[inline]
     pub fn call_fn_dynamic_raw(
         &self,
         fn_name: impl AsRef<str>,
@@ -249,7 +245,6 @@ pub fn shared_take_or_clone<T: Clone>(value: Shared<T>) -> T {
 
 /// Consume a [`Shared`] resource if is unique (i.e. not shared).
 #[inline(always)]
-#[must_use]
 pub fn shared_try_take<T>(value: Shared<T>) -> Result<T, Shared<T>> {
     Shared::try_unwrap(value)
 }
@@ -338,7 +333,6 @@ pub enum CallableFunction {
 }
 
 impl fmt::Debug for CallableFunction {
-    #[inline(always)]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             Self::Pure(_) => write!(f, "NativePureFunction"),
@@ -353,7 +347,6 @@ impl fmt::Debug for CallableFunction {
 }
 
 impl fmt::Display for CallableFunction {
-    #[inline(always)]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             Self::Pure(_) => write!(f, "NativePureFunction"),
@@ -369,7 +362,7 @@ impl fmt::Display for CallableFunction {
 
 impl CallableFunction {
     /// Is this a pure native Rust function?
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub fn is_pure(&self) -> bool {
         match self {
@@ -383,7 +376,7 @@ impl CallableFunction {
         }
     }
     /// Is this a native Rust method function?
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub fn is_method(&self) -> bool {
         match self {
@@ -397,7 +390,7 @@ impl CallableFunction {
         }
     }
     /// Is this an iterator function?
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub const fn is_iter(&self) -> bool {
         match self {
@@ -409,7 +402,7 @@ impl CallableFunction {
         }
     }
     /// Is this a Rhai-scripted function?
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub const fn is_script(&self) -> bool {
         match self {
@@ -420,7 +413,7 @@ impl CallableFunction {
         }
     }
     /// Is this a plugin function?
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub const fn is_plugin_fn(&self) -> bool {
         match self {
@@ -432,7 +425,7 @@ impl CallableFunction {
         }
     }
     /// Is this a native Rust function?
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub const fn is_native(&self) -> bool {
         match self {
@@ -445,7 +438,7 @@ impl CallableFunction {
         }
     }
     /// Get the access mode.
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub fn access(&self) -> FnAccess {
         match self {
@@ -457,7 +450,7 @@ impl CallableFunction {
         }
     }
     /// Get a shared reference to a native Rust function.
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub fn get_native_fn(&self) -> Option<&Shared<FnAny>> {
         match self {
@@ -472,7 +465,7 @@ impl CallableFunction {
     ///
     /// Not available under `no_function`.
     #[cfg(not(feature = "no_function"))]
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub const fn get_script_fn_def(&self) -> Option<&Shared<crate::ast::ScriptFnDef>> {
         match self {
@@ -481,7 +474,7 @@ impl CallableFunction {
         }
     }
     /// Get a reference to an iterator function.
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub fn get_iter_fn(&self) -> Option<IteratorFn> {
         match self {
@@ -493,9 +486,9 @@ impl CallableFunction {
         }
     }
     /// Get a shared reference to a plugin function.
-    #[inline(always)]
+    #[inline]
     #[must_use]
-    pub fn get_plugin_fn<'s>(&'s self) -> Option<&Shared<FnPlugin>> {
+    pub fn get_plugin_fn(&self) -> Option<&Shared<FnPlugin>> {
         match self {
             Self::Plugin(f) => Some(f),
             Self::Pure(_) | Self::Method(_) | Self::Iterator(_) => None,
@@ -557,6 +550,6 @@ impl<T: PluginFunction + 'static + SendSync> From<T> for CallableFunction {
 impl From<Shared<FnPlugin>> for CallableFunction {
     #[inline(always)]
     fn from(func: Shared<FnPlugin>) -> Self {
-        Self::Plugin(func.into())
+        Self::Plugin(func)
     }
 }
