@@ -81,18 +81,18 @@ impl FuncInfo {
                 sig.push_str(") -> ");
                 sig.push_str(&return_type);
             } else {
-                sig.push_str(")");
+                sig.push(')');
             }
         } else {
             for x in 0..self.params {
-                sig.push_str("_");
+                sig.push('_');
                 if x < self.params - 1 {
                     sig.push_str(", ");
                 }
             }
 
             if self.func.is_script() {
-                sig.push_str(")");
+                sig.push(')');
             } else {
                 sig.push_str(") -> ?");
             }
@@ -102,7 +102,7 @@ impl FuncInfo {
     }
 }
 
-/// _(INTERNALS)_ Calculate a [`u64`] hash key from a namespace-qualified function name and
+/// _(internals)_ Calculate a [`u64`] hash key from a namespace-qualified function name and
 /// parameter types.
 /// Exported under the `internals` feature only.
 ///
@@ -112,10 +112,10 @@ impl FuncInfo {
 /// # Note
 ///
 /// The first module name is skipped.  Hashing starts from the _second_ module in the chain.
-#[inline(always)]
+#[inline]
 fn calc_native_fn_hash<'a>(
     modules: impl Iterator<Item = &'a str>,
-    fn_name: impl AsRef<str>,
+    fn_name: &str,
     params: &[TypeId],
 ) -> u64 {
     let hash_script = calc_qualified_fn_hash(modules, fn_name, params.len());
@@ -324,7 +324,7 @@ impl Module {
     /// let module = Module::new();
     /// assert!(module.is_empty());
     /// ```
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub fn is_empty(&self) -> bool {
         self.functions.is_empty()
@@ -366,7 +366,6 @@ impl Module {
     /// Exported under the `metadata` feature only.
     #[cfg(feature = "metadata")]
     #[inline(always)]
-    #[must_use]
     pub fn gen_fn_signatures(&self) -> impl Iterator<Item = String> + '_ {
         self.functions
             .values()
@@ -437,7 +436,7 @@ impl Module {
     /// module.set_var("answer", 42_i64);
     /// assert_eq!(module.get_var_value::<i64>("answer").unwrap(), 42);
     /// ```
-    #[inline(always)]
+    #[inline]
     pub fn set_var(
         &mut self,
         name: impl Into<Identifier>,
@@ -457,7 +456,6 @@ impl Module {
     /// Get a reference to a namespace-qualified variable.
     /// Name and Position in [`EvalAltResult`] are [`None`] and [`NONE`][Position::NONE] and must be set afterwards.
     #[inline(always)]
-    #[must_use]
     pub(crate) fn get_qualified_var(&self, hash_var: u64) -> Result<&Dynamic, Box<EvalAltResult>> {
         self.all_variables.get(&hash_var).ok_or_else(|| {
             EvalAltResult::ErrorVariableNotFound(String::new(), Position::NONE).into()
@@ -519,7 +517,7 @@ impl Module {
     /// By taking a mutable reference, it is assumed that some sub-modules will be modified.
     /// Thus the [`Module`] is automatically set to be non-indexed.
     #[cfg(not(feature = "no_module"))]
-    #[inline(always)]
+    #[inline]
     #[must_use]
     pub(crate) fn sub_modules_mut(&mut self) -> &mut BTreeMap<Identifier, Shared<Module>> {
         // We must assume that the user has changed the sub-modules
@@ -580,7 +578,7 @@ impl Module {
     /// module.set_sub_module("question", sub_module);
     /// assert!(module.get_sub_module("question").is_some());
     /// ```
-    #[inline(always)]
+    #[inline]
     pub fn set_sub_module(
         &mut self,
         name: impl Into<Identifier>,
@@ -624,16 +622,16 @@ impl Module {
     /// The _last entry_ in the list should be the _return type_ of the function.
     /// In other words, the number of entries should be one larger than the number of parameters.
     #[cfg(feature = "metadata")]
-    #[inline(always)]
+    #[inline]
     pub fn update_fn_metadata(&mut self, hash_fn: u64, arg_names: &[&str]) -> &mut Self {
         let param_names = arg_names
             .iter()
             .map(|&name| self.identifiers.get(name))
             .collect();
 
-        self.functions
-            .get_mut(&hash_fn)
-            .map(|f| f.param_names = param_names);
+        if let Some(f) = self.functions.get_mut(&hash_fn) {
+            f.param_names = param_names;
+        }
 
         self
     }
@@ -641,7 +639,7 @@ impl Module {
     /// Update the namespace of a registered function.
     ///
     /// The [`u64`] hash is returned by the [`set_native_fn`][Module::set_native_fn] call.
-    #[inline(always)]
+    #[inline]
     pub fn update_fn_namespace(&mut self, hash_fn: u64, namespace: FnNamespace) -> &mut Self {
         if let Some(f) = self.functions.get_mut(&hash_fn) {
             f.namespace = namespace;
@@ -652,7 +650,7 @@ impl Module {
     }
 
     /// Remap type ID.
-    #[inline(always)]
+    #[inline]
     #[must_use]
     fn map_type(map: bool, type_id: TypeId) -> TypeId {
         if !map {
@@ -706,7 +704,7 @@ impl Module {
         #[cfg(feature = "metadata")]
         param_names.shrink_to_fit();
 
-        let hash_fn = calc_native_fn_hash(empty(), &name, &param_types);
+        let hash_fn = calc_native_fn_hash(empty(), name.as_ref(), &param_types);
 
         self.functions.insert(
             hash_fn,
@@ -1207,7 +1205,7 @@ impl Module {
     /// Merge another [`Module`] into this [`Module`].
     #[inline(always)]
     pub fn merge(&mut self, other: &Self) -> &mut Self {
-        self.merge_filtered(other, &mut |_, _, _, _, _| true)
+        self.merge_filtered(other, &|_, _, _, _, _| true)
     }
 
     /// Merge another [`Module`] into this [`Module`] based on a filter predicate.
@@ -1292,14 +1290,12 @@ impl Module {
 
     /// Get an iterator to the sub-modules in the [`Module`].
     #[inline(always)]
-    #[must_use]
     pub fn iter_sub_modules(&self) -> impl Iterator<Item = (&str, Shared<Module>)> {
         self.modules.iter().map(|(k, m)| (k.as_str(), m.clone()))
     }
 
     /// Get an iterator to the variables in the [`Module`].
     #[inline(always)]
-    #[must_use]
     pub fn iter_var(&self) -> impl Iterator<Item = (&str, &Dynamic)> {
         self.variables.iter().map(|(k, v)| (k.as_str(), v))
     }
@@ -1307,7 +1303,6 @@ impl Module {
     /// Get an iterator to the functions in the [`Module`].
     #[inline(always)]
     #[allow(dead_code)]
-    #[must_use]
     pub(crate) fn iter_fn(&self) -> impl Iterator<Item = &FuncInfo> {
         self.functions.values().map(Box::as_ref)
     }
@@ -1322,7 +1317,6 @@ impl Module {
     /// 5) Shared reference to function definition [`ScriptFnDef`][crate::ast::ScriptFnDef].
     #[cfg(not(feature = "no_function"))]
     #[inline(always)]
-    #[must_use]
     pub(crate) fn iter_script_fn(
         &self,
     ) -> impl Iterator<
@@ -1360,7 +1354,6 @@ impl Module {
     #[cfg(not(feature = "no_function"))]
     #[cfg(not(feature = "internals"))]
     #[inline(always)]
-    #[must_use]
     pub fn iter_script_fn_info(
         &self,
     ) -> impl Iterator<Item = (FnNamespace, FnAccess, &str, usize)> {
@@ -1370,7 +1363,7 @@ impl Module {
             .map(|f| (f.namespace, f.access, f.name.as_str(), f.params))
     }
 
-    /// _(INTERNALS)_ Get an iterator over all script-defined functions in the [`Module`].
+    /// _(internals)_ Get an iterator over all script-defined functions in the [`Module`].
     /// Exported under the `internals` feature only.
     ///
     /// Function metadata includes:
@@ -1378,7 +1371,7 @@ impl Module {
     /// 2) Access mode ([`FnAccess::Public`] or [`FnAccess::Private`]).
     /// 3) Function name (as string slice).
     /// 4) Number of parameters.
-    /// 5) _(INTERNALS)_ Shared reference to function definition [`ScriptFnDef`][crate::ast::ScriptFnDef].
+    /// 5) _(internals)_ Shared reference to function definition [`ScriptFnDef`][crate::ast::ScriptFnDef].
     #[cfg(not(feature = "no_function"))]
     #[cfg(feature = "internals")]
     #[inline(always)]
@@ -1419,7 +1412,6 @@ impl Module {
     /// # }
     /// ```
     #[cfg(not(feature = "no_module"))]
-    #[must_use]
     pub fn eval_ast_as_new(
         mut scope: crate::Scope,
         ast: &crate::AST,
@@ -1529,13 +1521,13 @@ impl Module {
 
             // Index all variables
             module.variables.iter().for_each(|(var_name, value)| {
-                let hash_var = crate::calc_qualified_var_hash(path.iter().map(|&v| v), var_name);
+                let hash_var = crate::calc_qualified_var_hash(path.iter().copied(), var_name);
                 variables.insert(hash_var, value.clone());
             });
 
             // Index type iterators
             module.type_iterators.iter().for_each(|(&type_id, func)| {
-                type_iterators.insert(type_id, func.clone());
+                type_iterators.insert(type_id, *func);
                 contains_indexed_global_functions = true;
             });
 
@@ -1611,10 +1603,10 @@ impl Module {
     }
 
     /// Set a type iterator into the [`Module`].
-    #[inline(always)]
+    #[inline]
     pub fn set_iter(&mut self, type_id: TypeId, func: IteratorFn) -> &mut Self {
         if self.indexed {
-            self.all_type_iterators.insert(type_id, func.clone());
+            self.all_type_iterators.insert(type_id, func);
             self.contains_indexed_global_functions = true;
         }
         self.type_iterators.insert(type_id, func);
@@ -1660,7 +1652,7 @@ impl Module {
     }
 }
 
-/// _(INTERNALS)_ A chain of [module][Module] names to namespace-qualify a variable or function call.
+/// _(internals)_ A chain of [module][Module] names to namespace-qualify a variable or function call.
 /// Exported under the `internals` feature only.
 ///
 /// A [`u64`] offset to the current [`Scope`][crate::Scope] is cached for quick search purposes.
@@ -1678,7 +1670,6 @@ pub struct NamespaceRef {
 }
 
 impl fmt::Debug for NamespaceRef {
-    #[inline(always)]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         if let Some(index) = self.index {
             write!(f, "{} -> ", index)?;
@@ -1696,7 +1687,6 @@ impl fmt::Debug for NamespaceRef {
 }
 
 impl fmt::Display for NamespaceRef {
-    #[inline(always)]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         for Ident { name, .. } in self.path.iter() {
             write!(f, "{}{}", name, Token::DoubleColon.syntax())?;
@@ -1735,7 +1725,10 @@ impl NamespaceRef {
     #[inline(always)]
     #[must_use]
     pub fn new(&self) -> Self {
-        Default::default()
+        Self {
+            index: None,
+            path: StaticVec::new(),
+        }
     }
     /// Get the [`Scope`][crate::Scope] index offset.
     #[inline(always)]
