@@ -1,6 +1,6 @@
 //! Module implementing the [`AST`] optimizer.
 
-use crate::ast::{Expr, OpAssignment, Stmt};
+use crate::ast::{Expr, OpAssignment, Stmt, AST_OPTION_FLAGS::*};
 use crate::dynamic::AccessMode;
 use crate::engine::{KEYWORD_DEBUG, KEYWORD_EVAL, KEYWORD_FN_PTR, KEYWORD_PRINT, KEYWORD_TYPE_OF};
 use crate::fn_builtin::get_builtin_binary_op_fn;
@@ -18,6 +18,9 @@ use std::{
     mem,
 };
 
+#[cfg(not(feature = "no_closure"))]
+use crate::engine::KEYWORD_IS_SHARED;
+
 /// Level of optimization performed.
 #[derive(Debug, Eq, PartialEq, Hash, Clone, Copy)]
 pub enum OptimizationLevel {
@@ -118,42 +121,40 @@ impl<'a> OptimizerState<'a> {
             }
         })
     }
-}
+    /// Call a registered function
+    #[inline(always)]
+    pub fn call_fn_with_constant_arguments(
+        &self,
+        fn_name: &str,
+        arg_values: &mut [Dynamic],
+    ) -> Option<Dynamic> {
+        self.engine
+            .call_native_fn(
+                &Default::default(),
+                &mut Default::default(),
+                self.lib,
+                fn_name,
+                calc_fn_hash(fn_name, arg_values.len()),
+                &mut arg_values.iter_mut().collect::<StaticVec<_>>(),
+                false,
+                false,
+                Position::NONE,
+            )
+            .ok()
+            .map(|(v, _)| v)
+    }
+    // Has a system function a Rust-native override?
+    pub fn has_native_fn(&self, hash_script: u64, arg_types: &[TypeId]) -> bool {
+        let hash_params = calc_fn_params_hash(arg_types.iter().cloned());
+        let hash = combine_hashes(hash_script, hash_params);
 
-// Has a system function a Rust-native override?
-fn has_native_fn(state: &OptimizerState, hash_script: u64, arg_types: &[TypeId]) -> bool {
-    let hash_params = calc_fn_params_hash(arg_types.iter().cloned());
-    let hash = combine_hashes(hash_script, hash_params);
-
-    // First check registered functions
-    state.engine.global_namespace.contains_fn(hash)
+        // First check registered functions
+        self.engine.global_namespace.contains_fn(hash)
             // Then check packages
-            || state.engine.global_modules.iter().any(|m| m.contains_fn(hash))
+            || self.engine.global_modules.iter().any(|m| m.contains_fn(hash))
             // Then check sub-modules
-            || state.engine.global_sub_modules.values().any(|m| m.contains_qualified_fn(hash))
-}
-
-/// Call a registered function
-fn call_fn_with_constant_arguments(
-    state: &OptimizerState,
-    fn_name: &str,
-    arg_values: &mut [Dynamic],
-) -> Option<Dynamic> {
-    state
-        .engine
-        .call_native_fn(
-            &mut Default::default(),
-            &mut Default::default(),
-            state.lib,
-            fn_name,
-            calc_fn_hash(fn_name, arg_values.len()),
-            &mut arg_values.iter_mut().collect::<StaticVec<_>>(),
-            false,
-            false,
-            Position::NONE,
-        )
-        .ok()
-        .map(|(v, _)| v)
+            || self.engine.global_sub_modules.values().any(|m| m.contains_qualified_fn(hash))
+    }
 }
 
 /// Optimize a block of [statements][Stmt].
@@ -200,23 +201,24 @@ fn optimize_stmt_block(
         // Optimize each statement in the block
         statements.iter_mut().for_each(|stmt| {
             match stmt {
-                // Add constant literals into the state
-                Stmt::Const(value_expr, x, _, _) => {
-                    optimize_expr(value_expr, state, false);
+                Stmt::Var(value_expr, x, options, _) => {
+                    if options.contains(AST_OPTION_CONSTANT) {
+                        // Add constant literals into the state
+                        optimize_expr(value_expr, state, false);
 
-                    if value_expr.is_constant() {
-                        state.push_var(
-                            &x.name,
-                            AccessMode::ReadOnly,
-                            value_expr.get_literal_value(),
-                        );
+                        if value_expr.is_constant() {
+                            state.push_var(
+                                &x.name,
+                                AccessMode::ReadOnly,
+                                value_expr.get_literal_value(),
+                            );
+                        }
+                    } else {
+                        // Add variables into the state
+                        optimize_expr(value_expr, state, false);
+                        state.push_var(&x.name, AccessMode::ReadWrite, None);
                     }
                 }
-                // Add variables into the state
-                Stmt::Let(value_expr, x, _, _) => {
-                    optimize_expr(value_expr, state, false);
-                    state.push_var(&x.name, AccessMode::ReadWrite, None);
-                }
                 // Optimize the statement
                 _ => optimize_stmt(stmt, state, preserve_result),
             }
@@ -231,11 +233,7 @@ fn optimize_stmt_block(
             .find_map(|(i, stmt)| match stmt {
                 stmt if !is_pure(stmt) => Some(i),
 
-                Stmt::Let(e, _, _, _) | Stmt::Const(e, _, _, _) | Stmt::Expr(e)
-                    if !e.is_constant() =>
-                {
-                    Some(i)
-                }
+                Stmt::Var(e, _, _, _) | Stmt::Expr(e) if !e.is_constant() => Some(i),
 
                 #[cfg(not(feature = "no_module"))]
                 Stmt::Import(e, _, _) if !e.is_constant() => Some(i),
@@ -561,6 +559,9 @@ fn optimize_stmt(stmt: &mut Stmt, state: &mut OptimizerState, preserve_result: b
         // while expr { block }
         Stmt::While(condition, body, _) => {
             optimize_expr(condition, state, false);
+            if let Expr::BoolConstant(true, pos) = condition {
+                *condition = Expr::Unit(*pos);
+            }
             let block = mem::take(body.statements_mut()).into_vec();
             *body.statements_mut() = optimize_stmt_block(block, state, false, true, false).into();
 
@@ -585,8 +586,9 @@ fn optimize_stmt(stmt: &mut Stmt, state: &mut OptimizerState, preserve_result: b
             }
         }
         // do { block } while false | do { block } until true -> { block }
-        Stmt::Do(body, Expr::BoolConstant(true, _), false, _)
-        | Stmt::Do(body, Expr::BoolConstant(false, _), true, _) => {
+        Stmt::Do(body, Expr::BoolConstant(x, _), options, _)
+            if *x == options.contains(AST_OPTION_NEGATED) =>
+        {
             state.set_dirty();
             let block_pos = body.position();
             let block = mem::take(body.statements_mut()).into_vec();
@@ -608,7 +610,9 @@ fn optimize_stmt(stmt: &mut Stmt, state: &mut OptimizerState, preserve_result: b
             *x.2.statements_mut() = optimize_stmt_block(body, state, false, true, false).into();
         }
         // let id = expr;
-        Stmt::Let(expr, _, _, _) => optimize_expr(expr, state, false),
+        Stmt::Var(expr, _, options, _) if !options.contains(AST_OPTION_CONSTANT) => {
+            optimize_expr(expr, state, false)
+        }
         // import expr as var;
         #[cfg(not(feature = "no_module"))]
         Stmt::Import(expr, _, _) => optimize_expr(expr, state, false),
@@ -705,14 +709,14 @@ fn optimize_expr(expr: &mut Expr, state: &mut OptimizerState, _chaining: bool) {
         }
         // lhs.rhs
         #[cfg(not(feature = "no_object"))]
-        Expr::Dot(x, _) if !_chaining => match (&mut x.lhs, &mut x.rhs) {
+        Expr::Dot(x,_, _) if !_chaining => match (&mut x.lhs, &mut x.rhs) {
             // map.string
             (Expr::Map(m, pos), Expr::Property(p)) if m.0.iter().all(|(_, x)| x.is_pure()) => {
                 let prop = p.2.0.as_str();
                 // Map literal where everything is pure - promote the indexed item.
                 // All other items can be thrown away.
                 state.set_dirty();
-                *expr = mem::take(&mut m.0).into_iter().find(|(x, _)| &x.name == prop)
+                *expr = mem::take(&mut m.0).into_iter().find(|(x, _)| x.name == prop)
                             .map(|(_, mut expr)| { expr.set_position(*pos); expr })
                             .unwrap_or_else(|| Expr::Unit(*pos));
             }
@@ -723,11 +727,11 @@ fn optimize_expr(expr: &mut Expr, state: &mut OptimizerState, _chaining: bool) {
         }
         // ....lhs.rhs
         #[cfg(not(feature = "no_object"))]
-        Expr::Dot(x, _) => { optimize_expr(&mut x.lhs, state, false); optimize_expr(&mut x.rhs, state, _chaining); }
+        Expr::Dot(x,_, _) => { optimize_expr(&mut x.lhs, state, false); optimize_expr(&mut x.rhs, state, _chaining); }
 
         // lhs[rhs]
         #[cfg(not(feature = "no_index"))]
-        Expr::Index(x, _) if !_chaining => match (&mut x.lhs, &mut x.rhs) {
+        Expr::Index(x, _, _) if !_chaining => match (&mut x.lhs, &mut x.rhs) {
             // array[int]
             (Expr::Array(a, pos), Expr::IntegerConstant(i, _))
                 if *i >= 0 && (*i as usize) < a.len() && a.iter().all(Expr::is_pure) =>
@@ -791,7 +795,7 @@ fn optimize_expr(expr: &mut Expr, state: &mut OptimizerState, _chaining: bool) {
         },
         // ...[lhs][rhs]
         #[cfg(not(feature = "no_index"))]
-        Expr::Index(x, _) => { optimize_expr(&mut x.lhs, state, false); optimize_expr(&mut x.rhs, state, _chaining); }
+        Expr::Index(x, _, _) => { optimize_expr(&mut x.lhs, state, false); optimize_expr(&mut x.rhs, state, _chaining); }
         // ``
         Expr::InterpolatedString(x, pos) if x.is_empty() => {
             state.set_dirty();
@@ -944,32 +948,36 @@ fn optimize_expr(expr: &mut Expr, state: &mut OptimizerState, _chaining: bool) {
         Expr::FnCall(x, pos)
                 if !x.is_qualified() // Non-qualified
                 && state.optimization_level == OptimizationLevel::Simple // simple optimizations
-                && x.args.len() == 2 // binary call
                 && x.args.iter().all(Expr::is_constant) // all arguments are constants
                 //&& !is_valid_identifier(x.name.chars()) // cannot be scripted
         => {
-            let mut arg_values: StaticVec<_> = x.args.iter().map(|e| match e {
-                                                                    Expr::Stack(slot, _) => x.constants[*slot].clone(),
-                                                                    _ => e.get_literal_value().unwrap()
-                                                                }).collect();
+            let arg_values = &mut x.args.iter().map(|e| match e {
+                                                            Expr::Stack(slot, _) => x.constants[*slot].clone(),
+                                                            _ => e.get_literal_value().unwrap()
+                                                        }).collect::<StaticVec<_>>();
 
             let arg_types: StaticVec<_> = arg_values.iter().map(Dynamic::type_id).collect();
 
-            // Search for overloaded operators (can override built-in).
-            if !has_native_fn(state, x.hashes.native, arg_types.as_ref()) {
-                if let Some(mut result) = get_builtin_binary_op_fn(x.name.as_ref(), &arg_values[0], &arg_values[1])
-                                            .and_then(|f| {
-                                                let ctx = (state.engine, x.name.as_ref(), state.lib).into();
-                                                let (first, second) = arg_values.split_first_mut().unwrap();
-                                                (f)(ctx, &mut [ first, &mut second[0] ]).ok()
-                                            })
-                                            .map(Expr::from)
-                {
-                    state.set_dirty();
-                    result.set_position(*pos);
-                    *expr = result;
-                    return;
+            let result = match x.name.as_str() {
+                KEYWORD_TYPE_OF if arg_values.len() == 1 => Some(state.engine.map_type_name(arg_values[0].type_name()).into()),
+                #[cfg(not(feature = "no_closure"))]
+                KEYWORD_IS_SHARED if arg_values.len() == 1 => Some(Dynamic::FALSE),
+                // Overloaded operators can override built-in.
+                _ if x.args.len() == 2 && !state.has_native_fn(x.hashes.native, arg_types.as_ref()) => {
+                    get_builtin_binary_op_fn(x.name.as_ref(), &arg_values[0], &arg_values[1])
+                        .and_then(|f| {
+                            let ctx = (state.engine, x.name.as_ref(), state.lib).into();
+                            let (first, second) = arg_values.split_first_mut().unwrap();
+                            (f)(ctx, &mut [ first, &mut second[0] ]).ok()
+                        })
                 }
+                _ => None
+            };
+
+            if let Some(result) = result {
+                state.set_dirty();
+                *expr = Expr::from_dynamic(result, *pos);
+                return;
             }
 
             x.args.iter_mut().for_each(|a| optimize_expr(a, state, false));
@@ -997,30 +1005,21 @@ fn optimize_expr(expr: &mut Expr, state: &mut OptimizerState, _chaining: bool) {
             let has_script_fn = false;
 
             if !has_script_fn {
-                let mut arg_values: StaticVec<_> = x.args.iter().map(|e| match e {
-                                                                        Expr::Stack(slot, _) => x.constants[*slot].clone(),
-                                                                        _ => e.get_literal_value().unwrap()
-                                                                    }).collect();
+                let arg_values = &mut x.args.iter().map(|e| match e {
+                                                                Expr::Stack(slot, _) => x.constants[*slot].clone(),
+                                                                _ => e.get_literal_value().unwrap()
+                                                            }).collect::<StaticVec<_>>();
 
-                // Save the typename of the first argument if it is `type_of()`
-                // This is to avoid `call_args` being passed into the closure
-                let arg_for_type_of = if x.name == KEYWORD_TYPE_OF && arg_values.len() == 1 {
-                    state.engine.map_type_name(arg_values[0].type_name())
-                } else {
-                    ""
+                let result = match x.name.as_str() {
+                    KEYWORD_TYPE_OF if arg_values.len() == 1 => Some(state.engine.map_type_name(arg_values[0].type_name()).into()),
+                    #[cfg(not(feature = "no_closure"))]
+                    KEYWORD_IS_SHARED if arg_values.len() == 1 => Some(Dynamic::FALSE),
+                    _ => state.call_fn_with_constant_arguments(x.name.as_ref(), arg_values)
                 };
 
-                if let Some(mut result) = call_fn_with_constant_arguments(&state, x.name.as_ref(), &mut arg_values)
-                                            .or_else(|| if !arg_for_type_of.is_empty() {
-                                                // Handle `type_of()`
-                                                Some(arg_for_type_of.to_string().into())
-                                            } else {
-                                                None
-                                            }).map(Expr::from)
-                {
+                if let Some(result) = result {
                     state.set_dirty();
-                    result.set_position(*pos);
-                    *expr = result;
+                    *expr = Expr::from_dynamic(result, *pos);
                     return;
                 }
             }
@@ -1043,9 +1042,7 @@ fn optimize_expr(expr: &mut Expr, state: &mut OptimizerState, _chaining: bool) {
         // constant-name
         Expr::Variable(_, pos, x) if x.1.is_none() && state.find_constant(&x.2).is_some() => {
             // Replace constant with value
-            let pos = *pos;
-            *expr = Expr::from(state.find_constant(&x.2).unwrap().clone());
-            expr.set_position(pos);
+            *expr = Expr::from_dynamic(state.find_constant(&x.2).unwrap().clone(), *pos);
             state.set_dirty();
         }
 
